==> haskell-fmlist-0.9.3-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fmlist
version:              0.9.3
visibility:           public
id:                   fmlist-0.9.3-FsHub3sLbGwDSRiLzFjNWc
key:                  fmlist-0.9.3-FsHub3sLbGwDSRiLzFjNWc
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher
homepage:             https://github.com/sjoerdvisscher/fmlist
synopsis:             FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.

category:             Data
abi:                  b7670e98041de7692bc6312d86d86a34
exposed:              True
exposed-modules:      Data.FMList
import-dirs:          /usr/lib/ghc-8.10.1/site-local/fmlist-0.9.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/fmlist-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/fmlist-0.9.3
hs-libraries:         HSfmlist-0.9.3-FsHub3sLbGwDSRiLzFjNWc
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html:         /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fmlist-0.9.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fmlist
version:              0.9.3
visibility:           public
id:                   fmlist-0.9.3-CjtU4gaw8g6BhqzoD35oR9
key:                  fmlist-0.9.3-CjtU4gaw8g6BhqzoD35oR9
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher
homepage:             https://github.com/sjoerdvisscher/fmlist
synopsis:             FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.

category:             Data
abi:                  43a91d549a4e7e81b82c41ec2ba23a4c
exposed:              True
exposed-modules:      Data.FMList
import-dirs:          /usr/lib/ghc-8.10.2/site-local/fmlist-0.9.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/fmlist-0.9.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/fmlist-0.9.3
hs-libraries:         HSfmlist-0.9.3-CjtU4gaw8g6BhqzoD35oR9
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html:         /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
